@@ -1,26 +1,3 @@
-from __future__ import annotations
-
-import argparse
-import asyncio
-import json
-import logging
-import random
-import re
-import string
-import warnings
-from datetime import datetime, timedelta
-from collections import deque
-from io import BytesIO
-from typing import Optional
-
-import aiohttp
-import matplotlib
-import matplotlib.pyplot as plt
-import numpy
-from rich.logging import RichHandler
-
-from .version import __version__
-
 """
 Headless reddit /r/place 2022 updater.
 
@@ -50,6 +27,28 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 """
 
+from __future__ import annotations
+import re
+import json
+import random
+import argparse
+import logging
+import asyncio
+import string
+import warnings
+from io import BytesIO
+from typing import Optional
+from datetime import datetime, timedelta
+from collections import deque
+
+import numpy
+import aiohttp
+import matplotlib
+import matplotlib.pyplot as plt
+from rich.logging import RichHandler
+
+from .version import __version__
+
 logger = logging.getLogger()
 logging.basicConfig(format=r"[%(name)s] %(message)s", handlers=[RichHandler()])
 
@@ -186,7 +185,7 @@ class CNCOrderClient:
 
         asyncio.get_running_loop().create_task(self.ping())
 
-    async def receive_orders(self, new_map_callback = None):
+    async def receive_orders(self, new_map_callback=None):
         if not self.ws:
             return
 
@@ -210,7 +209,7 @@ class CNCOrderClient:
                 if new_map_callback:
                     new_map_callback(order_map)
 
-    async def load_map(self, map_url):
+    async def load_map(self, map_url) -> Optional[numpy.ndarray]:
         async with self.session.get(map_url) as resp:
             if resp.status != 200:
                 text = await resp.text()
@@ -261,7 +260,7 @@ class RedditPlaceClient:
         self.logger = logging.getLogger(f'PlaceCZ.reddit.{username}')
         self.debug = debug
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> RedditPlaceClient:
         self.logger.info("Logging in reddit user %s...", self.username)
         success = await self.login()
 
@@ -365,7 +364,7 @@ class RedditPlaceClient:
 
             return access_token, expires_in
 
-    async def refresh_access_token(self):
+    async def refresh_access_token(self) -> bool:
         result = await self.scrape_access_token()
         if not result:
             self.logger.error("Could not refresh access token!")
@@ -462,13 +461,13 @@ class RedditPlaceClient:
 
                 self.logger.info("Loaded full canvas (shape: %s, dtype: %s)",
                                  self.current_canvas.shape, self.current_canvas.dtype)
-        except aiohttp.ServerDisconnectedError:
+        except aiohttp.ClientError:
             logger.exception("Could not obtain current canvas!")
 
-    def get_pixels_to_update(self, order_map):
+    def get_pixels_to_update(self, order_map) -> list:
         if self.current_canvas is None:
             self.logger.warning("Current canvas not yet loaded, can't figure out pending pixels...")
-            return
+            return []
 
         to_update = []
 
@@ -677,7 +676,6 @@ async def main():
         asyncio.get_running_loop().set_debug(True)
         logging.getLogger('aiohttp.client').setLevel(logging.DEBUG)
 
-
     tasks = [asyncio.create_task(runner.cnc_updater())]
 
     # Wait a few seconds before starting reddit clients to make sure C&C data has downloaded
